/*Global styles file*/
body {
	margin:0 auto;
	width:100%;
	padding:0;
	font-size:12pt;
	background:#fff;
	color:#000;
	line-height:normal;
	font-family:Arial, Helvetica, sans-serif;
}
#wrapper {
	width: 90%;
	margin: 1% auto;
}
#header {
	width: 96%;
	border: 1px solid #d2d2d2;
	padding: 1%;
	text-align:center;
	margin-bottom:2%;
	float: left;
}
#main {
	width: 96%;
	float: left;
	border: 1px solid #d2d2d2;
	padding: 2%;
	margin-bottom: 2%;
}
#menu {
	display:none;
	float: left;
}

#content {
	width: 100%;
	float: left;
	border: none;
}
#footer {
	float: left;
	width: 96%;
	padding: 2%;
	margin-bottom: 2%;
	border: 1px solid #d2d2d2;
}

/* data table styles*/
#data table {
	border-collapse: collapse;
	width: 100%;
	text-align: center;
}
thead {
	display: table-header-group;
}
tbody {
	display: table-row-group;
}
tfoot {
	display: table-footer-group;
}
#data table, #data th, #data td {
	border: 1px solid #f0e8da;
}
#data th {
	width: 20%;
	font-size: 10pt;
	background: #f0e8da;
	color: #490000;
	font-weight: normal;
}
#data th, #data td {
	padding: 5px;
}
#data tr {
	background: #fff;
}
#data tr:nth-child(odd) {
	background:#f9f6ed;
}
#data tr > td:first-child {
	text-align: left;
	padding-left: 2%;
}
#data .tfooter {
	background: #f5f5f5;
	font-weight: bold;
	color: #490000;
}
#data .space {
	background: #fff;
	border: 1px solid #fff;
}
#data p.print-only {
	font-size: 10pt;
	display:block;
}


fieldset
{ 
  display: none;
}
