{% extends "admin_skel/base.html" %}
{% load i18n %}
{% load extras %}

{% block main %}
    <div id="main" class="rc10">
        <div id="menu">
            {% block menu %}
            <ul>
                {% for item in menu %}
                <li>
                    <a {% if item.url %}href="{{ item.url }}"{% else %}href="#" onclick="changeState('menu{{ forloop.counter }}'); return false;"{% endif %}>{{ item.title }}</a>
                    {% if item.submenu %}
                    <ul id="menu{{ forloop.counter }}" {% if item.opened %}style="display:block"{% endif %}>
                        {% for subitem in item.submenu %}
                        <li {% if subitem.selected %}class="selected"{% endif %}>
                            <a href="{{ subitem.url }}">{{ subitem.title }}</a>
                        </li>
                        {% endfor %}
                    </ul>
                    {% endif %}
                </li>
                {% endfor %}
                <li style="margin-top: 2em;"><a href="{% url logout %}">{% trans "Logout" %}</a></li>
            </ul>
            {% endblock %}
        </div>
        <div id="content">
{% block content %}
Please, override block "content"
{% endblock %}
        </div>
    </div>
{% endblock %}
