
/*Global styles file*/
body {
	margin:0 auto;
	width:100%;
	padding:0;
	font-size:12pt;
	background:#fff;
	color:#000;
	line-height:normal;
	font-family:Arial, Helvetica, sans-serif;
}

.graph 
{ 
  margin-bottom: 1em;
}

h1
{ 
  font-size: 1.4em;
  margin: 0 0 1.5em 0;
  text-align: center;
}

h2
{ 
  margin: 1em 0 0.5em 0;
  font-size: 1.2em;
}

p 
{ 
  margin-bottom: 1em;
}

fieldset
{ 
  border: 1px dotted;
  margin-bottom: 1em;
  /* width: 30%; */
}

#wrapper {
	width: 90%;
	margin: 1% auto;
}
#header
{
  width: 100%;
  margin-bottom: 1%;
  border: 1px solid #d2d2d2;
  text-align:center;
  float: left;
  /* background: url('/media/img/header_bg.png') repeat-x; */
}

#header_wrapper
{ 
  height: 101px; 
  /* background: url('/media/img/header.png') no-repeat left; */

}

#main {
	width: 96%;
	float: left;
	border: 1px solid #d2d2d2;
	padding: 2%;
	margin-bottom: 2%;
}
#menu {
	width: 15%;
	float: left;
}
#menu a
{ 
  color: #00a3f3;
  font-weight: bold;
  font-size: 14pt;
}

#menu a:hover
{ 
  color: #5ec9fd;
}

#menu ul li ul {
	display: none;
}
#menu ul li ul li a {
	font-size: 12pt;
	padding-left: 5%;
	font-weight: normal;
}
#menu ul li ul li.selected a
{
  font-weight: bold;
}

#content {
	width: 82%;
	float: left;
	padding-left: 2%;
	border-left: 1px dotted #d2d2d2;
}
#footer {
	float: left;
	width: 96%;
	padding: 2%;
	margin-bottom: 2%;
	border: 1px solid #d2d2d2;
}

/* data table styles*/
table.data {
	border-collapse: collapse;
	width: 100%;
	/* text-align: center; */
}
thead {
	display: table-header-group;
}
tbody {
	display: table-row-group;
}
tfoot {
	display: table-footer-group;
}
table.data, table.data th, table.data td {
	border: 1px solid #f0e8da;
}
table.data th {
	width: 20%;
	font-size: 10pt;
	background: #f0e8da;
	color: #490000;
	font-weight: normal;
}
table.data th, table.data td {
	padding: 5px;
}
table.data tr {
	background: #fff;
}
table.data tr:nth-child(odd) {
	background:#f9f6ed;
}
table.data tr > td:first-child {
	text-align: left;
	padding-left: 2%; 
}
table.data tfoot {
	background: #f5f5f5;
	font-weight: bold;
	color: #490000;
}
table.data .space {
	background: #fff;
	border: 1px solid #fff;
}
p.print-only {
	font-size: 10pt;
	display:none;
}

/* .edit_form */
fieldset form > table {
	border-collapse: collapse;
	/* width: 40%; */
	text-align: left;
	margin-bottom:2%;
}

fieldset form > table, fieldset form > th, fieldset form > td {
	border: 1px solid #f0e8da;
}
fieldset th label {
	width: 20%;
	font-size: 11pt;
	color: #490000;
	font-weight: normal;
}
fieldset td {
	font-size: 10pt;
	color: #333;
	font-style: oblique;
}
fieldset td textarea
{ 
  font-style: normal;
  
}
fieldset td input {
	font-size: 11pt;
}
fieldset th, fieldset td {
	padding: 5px;
}
fieldset tr {
	background: #fff;
}
fieldset tr:nth-child(odd) {
	background:#f9f6ed;
}

fieldset td ul.errorlist li {
	color: #ff0000;
	font-size:8pt;
}


a.button
{ 
  display: inline-block;
  padding: 4px 8px 4px 8px;
  border: 1px solid;
  margin: 0.5em;
  text-decoration: none;
  color: #490000;
  font-size: 0.8em;
}

a.icon_plus
{ 
  padding: 4px 8px 4px 18px;
  background: url('/media/images/admin/plus.png') no-repeat 6px center;
}

a.button:hover
{ 
  background-color: #f0e8da;
}