{% load admin_media %}
<!DOCTYPE html >
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ru-ru" lang="ru-ru">
<head>
    <title>{% block title %}{% endblock %}</title>
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
    <script type="text/javascript" src="{% admin_media_prefix %}js/rounded-corners-min.js"></script>
    <link rel="stylesheet" href="{% admin_media_prefix %}css/reset.css" type="text/css" /> 
    <link rel="stylesheet" href="{% admin_media_prefix %}css/style.css" type="text/css" media="all" />
    <link rel="stylesheet" href="{% admin_media_prefix %}css/print.css" type="text/css" media="print"/>
    {% block scripts %}{% endblock %}
    <script type="text/javascript">
	  function changeState(divId) {
	  if (document.getElementById(divId).style.display == "block") {
	  document.getElementById(divId).style.display = "none";
	  } else {
	  document.getElementById(divId).style.display = "block";
	  }
	  }
	</script> 
</head>
<body>
{% block body %}
<div id="wrapper">
    <div id="header" class="rc10">
      <div id="header_wrapper">{% block header %}Please, override block "header"{% endblock %}</div>
    </div>
    {% block main %}
    Please, override block "main"
    {% endblock %}
    <div id="footer" class="rc10">{% block footer %}Please, override block "footer"{% endblock %}</div>
{% endblock %}
</body>
</html>
