{% extends "admin_skel/base.html" %}
{% load i18n %}

{% block main %}
<p>{% trans "You was successfully signed out" %}</p>
<p><a href="{% url admin:index %}">{% trans "Sign in again" %}</a></p>
<p><a href="/">{% trans "Go to website" %}</a></p>
{% endblock %}
