{% extends "admin_skel/base.html" %}
{% load i18n %}

{% block main %}
{% if error_message %}
<p class="errornote">{{ error_message }}</p>
{% endif %}
<fieldset>
    <legend>{% trans "Secured area. Please, sign in" %}</legend>
    <form action="" method="post">
        {% csrf_token %}
        <table>
            {{ form.as_table }}
        </table>
        <input type="submit" value="{% trans "Sign in" %}" />
    </form>
</fieldset>
<script type="text/javascript">
    document.getElementById('id_username').focus()
</script>


{% endblock %}
